Radio Button Group Example
===============================================================================

:download:`radio_group.enaml <../../../examples/stdlib/radio_group.enaml>`

.. literalinclude:: ../../../examples/stdlib/radio_group.enaml
    :language: python

::

 $ enaml-run radio_group.enaml

.. image:: images/radio_group.png
